@@ -1,13 +1,13 @@
-# Copyrights 2001-2010 by Mark Overmeer.
+# Copyrights 2001-2012 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 use strict;
 use warnings;
 
 package Mail::Box::Manager;
 use vars '$VERSION';
-$VERSION = '2.095';
+$VERSION = '2.105';
 
 use base 'Mail::Reporter';
 
@@ -27,6 +27,7 @@ my @basic_folder_types =
   , [ maildir => 'Mail::Box::Maildir' ]
   , [ pop     => 'Mail::Box::POP3'    ]
   , [ pop3    => 'Mail::Box::POP3'    ]
+  , [ pop3s   => 'Mail::Box::POP3s'   ]
   , [ imap    => 'Mail::Box::IMAP4'   ]
   , [ imap4   => 'Mail::Box::IMAP4'   ]
   );
@@ -160,6 +161,12 @@ sub open(@)
         my $port = $args{server_port} ||= 110;
         $args{folder} = $name = "pop3://$un\@$srv:$port";
     }
+    elsif($type eq 'pop3s')
+    {   my $un   = $args{username}    ||= $ENV{USER} || $ENV{LOGIN};
+        my $srv  = $args{server_name} ||= 'localhost';
+        my $port = $args{server_port} ||= 995;
+        $args{folder} = $name = "pop3s://$un\@$srv:$port";
+    }
     elsif($type eq 'imap4')
     {   my $un   = $args{username}    ||= $ENV{USER} || $ENV{LOGIN};
         my $srv  = $args{server_name} ||= 'localhost';
@@ -536,7 +543,7 @@ sub decodeFolderURL($)
        my ($type, $username, $password, $hostname, $port, $path)
           = $name =~ m!^(\w+)\:             # protocol
                        (?://
-                          (?:([^:@./]*)     # username
+                          (?:([^:@/]*)      # username
                             (?:\:([^@/]*))? # password
                            \@)?
                            ([\w.-]+)?       # hostname
