@@ -1,4 +1,4 @@
-# Copyrights 2001-2011 by Mark Overmeer.
+# Copyrights 2001-2012 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.00.
@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.099';
+$VERSION = '2.105';
 
 use base 'Mail::Reporter';
 
@@ -283,8 +283,8 @@ sub body(;$@)
         return $body;
     }
 
-    $self->log(INTERNAL => "wrong type of body for message $rawbody")
-        unless ref $rawbody && $rawbody->isa('Mail::Message::Body');
+    ref $rawbody && $rawbody->isa('Mail::Message::Body')
+        or $self->log(INTERNAL => "wrong type of body for message $rawbody");
 
     # Bodies of real messages must be encoded for safe transmission.
     # Message parts will get encoded on the moment the whole multipart
@@ -304,15 +304,8 @@ sub body(;$@)
 
 
 sub decoded(@)
-{   my ($self, %args) = @_;
-
-    my $body    = $self->body->load or return;
-    my $decoded = $body->decoded
-      ( result_type => $args{result_type}
-      , charset     => $args{charset}
-      );
-
-    $decoded;
+{   my $body = shift->body->load;
+    $body ? $body->decoded(@_) : undef;
 }
 
 
