@@ -1,13 +1,13 @@
-# Copyrights 2001-2010 by Mark Overmeer.
+# Copyrights 2001-2012 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 use strict;
 use warnings;
 
 package Mail::Message::Body::Multipart;
 use vars '$VERSION';
-$VERSION = '2.095';
+$VERSION = '2.105';
 
 use base 'Mail::Message::Body';
 
@@ -21,8 +21,7 @@ use Carp;
 sub init($)
 {   my ($self, $args) = @_;
     my $based = $args->{based_on};
-    $args->{mime_type} ||=
-        defined $based ? $based->mimeType : 'multipart/mixed';
+    $args->{mime_type} ||= defined $based ? $based->type : 'multipart/mixed';
 
     $self->SUPER::init($args);
 
@@ -53,9 +52,10 @@ sub init($)
             = defined $preamble ? $preamble : $based->preamble;
 
         $self->{MMBM_parts}
-            = @parts              ? \@parts
-            : $based->isMultipart ? [ $based->parts('ACTIVE') ]
-            : [];
+            = @parts ? \@parts
+            : !$args->{parts} && $based->isMultipart
+                     ? [ $based->parts('ACTIVE') ]
+            :          [];
 
         $self->{MMBM_epilogue}
             = defined $epilogue ? $epilogue : $based->epilogue;
@@ -266,7 +266,8 @@ sub read($$$$)
          );
 
         last unless $part->readFromParser($parser, $bodytype);
-        push @parts, $part;
+        push @parts, $part
+            if $part->head->names || $part->body->size;
     }
     $self->{MMBM_parts} = \@parts;
 
@@ -393,8 +394,6 @@ sub parts(;$)
 sub part($) { shift->{MMBM_parts}[shift] }
 
 
-my $unique_boundary = time;
-
 sub boundary(;$)
 {   my $self  = shift;
     my $mime  = $self->type;
@@ -404,7 +403,7 @@ sub boundary(;$)
         return $boundary if defined $boundary;
     }
 
-    my $boundary = @_ && defined $_[0] ? (shift) : "boundary-".$unique_boundary++;
+    my $boundary = @_ && defined $_[0] ? (shift) : "boundary-".int rand(1000000);
     $self->type->attribute(boundary => $boundary);
 }
 
