@@ -1,4 +1,4 @@
-# Copyrights 2001-2012 by Mark Overmeer.
+# Copyrights 2001-2012 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.00.
@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message::Head::Complete;
 use vars '$VERSION';
-$VERSION = '2.102';
+$VERSION = '2.105';
 
 use base 'Mail::Message::Head';
 
@@ -143,7 +143,7 @@ sub grepNames(@)
 
 
 my @skip_none = qw/content-transfer-encoding content-disposition
-                   content-description/;
+                   content-description content-id/;
 
 my %skip_none = map { ($_ => 1) } @skip_none;
 
